==> apo-ws-client-6.00.10.4-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerLienVetVdi.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="lienVetVdi" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VdiFractionnerVetDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lienVetVdi"
})
@XmlRootElement(name = "creerLienVetVdi", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerLienVetVdi {

    @XmlElement(required = true)
    protected VdiFractionnerVetDTO lienVetVdi;

    /**
     * Obtient la valeur de la propriété lienVetVdi.
     * 
     * @return
     *     possible object is
     *     {@link VdiFractionnerVetDTO }
     *     
     */
    public VdiFractionnerVetDTO getLienVetVdi() {
        return lienVetVdi;
    }

    /**
     * Définit la valeur de la propriété lienVetVdi.
     * 
     * @param value
     *     allowed object is
     *     {@link VdiFractionnerVetDTO }
     *     
     */
    public void setLienVetVdi(VdiFractionnerVetDTO value) {
        this.lienVetVdi = value;
    }

}

==> apo-ws-client-6.00.50.4-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerLienVetVdi.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="lienVetVdi" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VdiFractionnerVetDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lienVetVdi"
})
@XmlRootElement(name = "creerLienVetVdi", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerLienVetVdi {

    @XmlElement(required = true)
    protected VdiFractionnerVetDTO lienVetVdi;

    /**
     * Obtient la valeur de la propriété lienVetVdi.
     * 
     * @return
     *     possible object is
     *     {@link VdiFractionnerVetDTO }
     *     
     */
    public VdiFractionnerVetDTO getLienVetVdi() {
        return lienVetVdi;
    }

    /**
     * Définit la valeur de la propriété lienVetVdi.
     * 
     * @param value
     *     allowed object is
     *     {@link VdiFractionnerVetDTO }
     *     
     */
    public void setLienVetVdi(VdiFractionnerVetDTO value) {
        this.lienVetVdi = value;
    }

}
